# Generated by roxygen2: do not edit by hand

S3method(print,drugdevelopResult)
export(EPsProg2)
export(EPsProg23)
export(EPsProg23_binary)
export(EPsProg23_normal)
export(EPsProg2_binary)
export(EPsProg2_normal)
export(EPsProg3)
export(EPsProg3_binary)
export(EPsProg3_normal)
export(EPsProg4)
export(EPsProg4_binary)
export(EPsProg4_normal)
export(EPsProg_L)
export(EPsProg_L2)
export(EPsProg_R)
export(EPsProg_R2)
export(EPsProg_binary_L)
export(EPsProg_binary_L2)
export(EPsProg_binary_R)
export(EPsProg_binary_R2)
export(EPsProg_multiple_normal)
export(EPsProg_multiple_tte)
export(EPsProg_normal_L)
export(EPsProg_normal_L2)
export(EPsProg_normal_R)
export(EPsProg_normal_R2)
export(EPsProg_tte)
export(Ed3_L)
export(Ed3_L2)
export(Ed3_R)
export(Ed3_R2)
export(Ed3_tte)
export(En3_binary_L)
export(En3_binary_L2)
export(En3_binary_R)
export(En3_binary_R2)
export(En3_normal_L)
export(En3_normal_L2)
export(En3_normal_R)
export(En3_normal_R2)
export(Epgo23)
export(Epgo23_binary)
export(Epgo23_normal)
export(Epgo_L2)
export(Epgo_R2)
export(Epgo_binary_L2)
export(Epgo_binary_R2)
export(Epgo_normal_L2)
export(Epgo_normal_R2)
export(Epgo_tte)
export(Ess_binary)
export(Ess_multiple_normal)
export(Ess_multiple_tte)
export(Ess_normal)
export(Ess_tte)
export(PsProg_binary)
export(PsProg_normal)
export(PsProg_tte)
export(d3_skipII_tte)
export(dbivanorm)
export(drugdevelopR)
export(drugdevelopResult)
export(fmax)
export(fmin)
export(optimal_bias)
export(optimal_bias_binary)
export(optimal_bias_normal)
export(optimal_binary)
export(optimal_multiarm)
export(optimal_multiarm_binary)
export(optimal_multiarm_normal)
export(optimal_multiple_normal)
export(optimal_multiple_tte)
export(optimal_multitrial)
export(optimal_multitrial_binary)
export(optimal_multitrial_normal)
export(optimal_normal)
export(optimal_tte)
export(os_tte)
export(pgo_binary)
export(pgo_multiple_normal)
export(pgo_multiple_tte)
export(pgo_normal)
export(pgo_tte)
export(posp_normal)
export(prior_tte)
export(pw)
export(ss_binary)
export(ss_normal)
export(ss_tte)
export(utility2)
export(utility23)
export(utility23_binary)
export(utility23_normal)
export(utility2_binary)
export(utility2_normal)
export(utility3)
export(utility3_binary)
export(utility3_normal)
export(utility4)
export(utility4_binary)
export(utility4_normal)
export(utility_L)
export(utility_L2)
export(utility_R)
export(utility_R2)
export(utility_binary_L)
export(utility_binary_L2)
export(utility_binary_R)
export(utility_binary_R2)
export(utility_multiarm)
export(utility_multiarm_binary)
export(utility_multiarm_normal)
export(utility_multiple_normal)
export(utility_multiple_tte)
export(utility_normal_L)
export(utility_normal_L2)
export(utility_normal_R)
export(utility_normal_R2)
export(utility_tte)
import(doParallel)
import(foreach)
import(iterators)
import(parallel)
importFrom(MASS,mvrnorm)
importFrom(cubature,adaptIntegrate)
importFrom(msm,dtnorm)
importFrom(msm,ptnorm)
importFrom(msm,rtnorm)
importFrom(mvtnorm,dmvnorm)
importFrom(mvtnorm,pmvnorm)
importFrom(mvtnorm,qmvnorm)
importFrom(progressr,progressor)
importFrom(stats,dnorm)
importFrom(stats,integrate)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
