#' @title MultpleEndpoints_05
#' @editor Johannes Cepicka
#' @editDate 2022-08-16
#' @coverage
#' TESTCASE: REQUIREMENT


+ Setup: DOCUMENT ANY SETUP THAT NEEDS TO BE DONE FOR TESTING

+ Start documenting test case here!
